from django.core.urlresolvers import reverse
from django.db import models
from django.utils.translation import ugettext_lazy as _

from passerelle.base.models import BaseResource


class BaseAddresse(BaseResource):
    service_url = models.CharField(max_length=128, blank=False,
            default='https://api-adresse.data.gouv.fr/',
            verbose_name=_('Service URL'),
            help_text=_('Base Adresse Web Service URL'))

    category = _('Geographic information system')

    class Meta:
        verbose_name = _('Base Adresse Web Service')

    def get_absolute_url(self):
        return reverse('base_adresse-view', kwargs={'slug': self.slug})

    @classmethod
    def get_add_url(cls):
        return reverse('base_adresse-add')

    @classmethod
    def get_verbose_name(cls):
        return cls._meta.verbose_name

    @classmethod
    def get_icon_class(cls):
        return 'gis'
