import requests
import urllib
import urlparse

from django.core.urlresolvers import reverse
from django.http import Http404
from django.shortcuts import redirect
from django.views.generic.base import View, RedirectView
from django.views.generic.detail import SingleObjectMixin, DetailView
from django.views.generic.edit import CreateView, UpdateView, DeleteView

from passerelle import utils
from passerelle.base.views import ResourceView

from .models import BaseAddresse

from .forms import BaseAddresseForm


class BaseAddresseDetailView(DetailView):
    model = BaseAddresse
    template_name = 'base_adresse/base_adresse_detail.html'

    def get_context_data(self, **kwargs):
        context = super(BaseAddresseDetailView, self).get_context_data(**kwargs)
        return context


class BaseAddresseCreateView(CreateView):
    model = BaseAddresse
    form_class = BaseAddresseForm
    template_name = 'passerelle/manage/service_form.html'


class BaseAddresseUpdateView(UpdateView):
    model = BaseAddresse
    form_class = BaseAddresseForm
    template_name = 'passerelle/manage/service_form.html'


class BaseAddresseDeleteView(DeleteView):
    model = BaseAddresse
    template_name = 'passerelle/manage/service_confirm_delete.html'

    def get_success_url(self):
        return reverse('manage-home')


class SearchView(View, SingleObjectMixin):
    model = BaseAddresse

    def get(self, request, *args, **kwargs):
        raise NotImplementedError()


class SearchPathView(View, SingleObjectMixin):
    model = BaseAddresse

    def get(self, request, *args, **kwargs):
        raise NotImplementedError()


class ReverseView(View, SingleObjectMixin):
    model = BaseAddresse

    def get(self, request, *args, **kwargs):
        response_format = 'json'
        if 'format' in request.GET:
            response_format = request.GET['format']
        if response_format != 'json':
            raise NotImplementedError()
        lat = request.GET['lat']
        lon = request.GET['lon']

        scheme, netloc, path, params, query, fragment = urlparse.urlparse(
                self.get_object().service_url)
        path = '/reverse/'
        query = urllib.urlencode({'lat': lat, 'lon': lon})
        url = urlparse.urlunparse((scheme, netloc, path, params, query, fragment))

        result_response = requests.get(url)
        result = None

        for feature in result_response.json().get('features'):
            if not feature['geometry']['type'] == 'Point':
                continue # skip unknown
            result = {}
            result['lon'] = str(feature['geometry']['coordinates'][0])
            result['lat'] = str(feature['geometry']['coordinates'][1])
            result['address'] = {'country': 'France'}
            for prop in feature['properties']:
                if prop in ('city', 'postcode'):
                    result['address'][prop] = feature['properties'][prop]
                elif prop == 'housenumber':
                    result['address']['house_number'] = feature['properties'][prop]
                elif prop == 'label':
                    result['display_name'] = feature['properties'][prop]
                elif prop == 'name':
                    house_number = feature['properties'].get('housenumber')
                    value = feature['properties'][prop]
                    if house_number and value.startswith(house_number):
                        value = value[len(house_number):].strip()
                    result['address']['road'] = value
        return utils.response_for_json(request, result)
