# passerelle.contrib.teamnet_axel
# Copyright (C) 2015  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.core.urlresolvers import reverse
from django.views.generic import DetailView as GenericDetailView
from django.views.generic.edit import CreateView, UpdateView, DeleteView

from passerelle import utils

from .models import Management, Link, AxelException
from .forms import ManagementForm, ManagementUpdateForm
from . import soap

class ManagementDetailView(GenericDetailView):
    model = Management
    template_name = 'passerelle/contrib/teamnet_axel/detail.html'


class ManagementCreateView(CreateView):
    model = Management
    form_class = ManagementForm
    template_name = 'passerelle/manage/service_form.html'


class ManagementUpdateView(UpdateView):
    model = Management
    form_class = ManagementUpdateForm
    template_name = 'passerelle/manage/service_form.html'


class ManagementDeleteView(DeleteView):
    model = Management
    template_name = 'passerelle/manage/service_confirm_delete.html'

    def get_success_url(self):
        return reverse('manage-home')


class DetailView(GenericDetailView):
    model = Management

    def get_data(self, request, *args, **kwargs):
        raise NotImplementedError

    @utils.protected_api('can_access')
    @utils.to_json('api')
    def get(self, request, *args, **kwargs):
        return self.get_data(request, *args, **kwargs)


class PingView(DetailView):
    def get_data(self, request, *args, **kwargs):
        client = soap.get_client(self.get_object())
        res = {'ping': 'pong'}
        if 'debug' in request.GET:
            res['client'] = soap.client_to_jsondict(client)
        return res


class AuthView(DetailView):
    def get_data(self, request, *args, **kwargs):
        login = request.GET.get('login')
        pwd = request.GET.get('pwd')
        return self.get_object().auth(login, pwd)


class LinkView(DetailView):
    def get_data(self, request, *args, **kwargs):
        nameid = request.GET.get('NameID')
        if not nameid:
            raise AxelException('NameID required')
        login = request.GET.get('login')
        pwd = request.GET.get('pwd')
        resource = self.get_object()
        user = resource.auth(login, pwd)
        if not user:
            raise AxelException('authentication failed')
        if not 'idfamille' in user:
            raise AxelException('user without idfamille')
        famille = resource.get_famille(user['idfamille'])
        Link.objects.update_or_create(resource=resource,
                nameid=nameid, defaults={'login': login, 'pwd': pwd})
        user['_famille'] = famille
        user['_nameid'] = nameid
        return user


class UnlinkView(DetailView):
    def get_data(self, request, *args, **kwargs):
        nameid = request.GET.get('NameID')
        if not nameid:
            raise AxelException('NameID required')
        resource = self.get_object()
        logins = [v['login'] for v in Link.objects.filter(resource=resource, nameid=nameid).values('login')]
        Link.objects.filter(resource=resource, nameid=nameid).delete()
        if logins:
            return {'login_was': logins}
        else:
            return None


class FamilyView(DetailView):
    def get_data(self, request, *args, **kwargs):
        nameid = request.GET.get('NameID')
        if not nameid:
            raise AxelException('NameID required')
        resource = self.get_object()
        links = Link.objects.filter(resource=resource, nameid=nameid)
        if len(links) > 1:
            raise AxelException('multiple links')
        if not links:
            return None
        user = resource.auth(links[0].login, links[0].pwd)
        if not user:
            raise AxelException('authentication failed')
        if not 'idfamille' in user:
            raise AxelException('user without idfamille')
        famille = resource.get_famille(user['idfamille'])
        if not 'key' in kwargs:
            return famille
        else:
            return famille.get(kwargs['key'])
