import re

from django.utils.translation import ugettext_lazy as _

class SMSGatewayMixin(object):
    category = _('SMS Providers')

    @classmethod
    def clean_numbers(cls, destinations, default_country_code, prefix='+'):
        numbers = []
        for dest in destinations:
            # most gateways needs the number prefixed by the country code, this is
            # really unfortunate.
            number = ''.join(re.findall('[0-9]', dest))
            if dest.startswith('+'):
                pass # it already is fully qualified
            elif number.startswith('00'):
                # assumes 00 is international access code, remove it
                number = number[2:]
            elif number.startswith('0'):
                # local prefix, remove 0 and add default country code
                number = default_country_code + number[1:]
            numbers.append(prefix + number)
        return numbers

