from django.conf import settings
from django.conf.urls import patterns, include, url

from django.contrib import admin

from django.contrib.auth.decorators import login_required
from django.views.static import serve as static_serve

from .views import (HomePageView, ManageView, ManageAddView,
        LEGACY_APPS_PATTERNS, LegacyPageView, login, logout, menu_json)
from .urls_utils import decorated_includes, required, app_enabled
from .base.urls import access_urlpatterns
from .plugins import register_apps_urls

import choosit.urls
import clicrdv.urls
import gdc.urls
import mobyt.urls
import ovh.urls
import oxyd.urls
import pastell.urls
import concerto.urls
import bdp.urls
import base_adresse.urls

admin.autodiscover()

urlpatterns = patterns('',
    url(r'^$', HomePageView.as_view(), name='homepage'),
    url(r'^legacy/$', LegacyPageView.as_view(), name='legacy'),

    url(r'^manage/$', login_required(ManageView.as_view()), name='manage-home'),
    url(r'^manage/menu.json$', login_required(menu_json), name='menu-json'),
    url(r'^manage/add$', login_required(ManageAddView.as_view()), name='add-connector'),

    url(r'^media/(?P<path>.*)$', login_required(static_serve), {
        'document_root': settings.MEDIA_ROOT,
    }),
    url(r'^admin/', include(admin.site.urls)),

    url(r'^manage/access/',
        decorated_includes(login_required, include(access_urlpatterns))),
)

urlpatterns += required(
    app_enabled('choosit'),
    patterns('',
        url(r'^choosit/', include(choosit.urls.urlpatterns)),
        url(r'^manage/choosit/',
            decorated_includes(login_required, include(choosit.urls.management_urlpatterns))),
    )
)

urlpatterns += required(
    app_enabled('clicrdv'),
    patterns('',
        url(r'^clicrdv/', include(clicrdv.urls.urlpatterns)),
        url(r'^manage/clicrdv/',
            decorated_includes(login_required, include(clicrdv.urls.management_urlpatterns))),
    )
)

urlpatterns += required(
    app_enabled('gdc'),
    patterns('',
        url(r'^gdc/', include(gdc.urls.urlpatterns)),
        url(r'^manage/gdc/',
            decorated_includes(login_required, include(gdc.urls.management_urlpatterns))),
    )
)

urlpatterns += required(
    app_enabled('mobyt'),
    patterns('',
        url(r'^mobyt/', include(mobyt.urls.urlpatterns)),
        url(r'^manage/mobyt/',
            decorated_includes(login_required, include(mobyt.urls.management_urlpatterns))),
    )
)

urlpatterns += required(
    app_enabled('ovh'),
    patterns('',
        url(r'^ovh/', include(ovh.urls.urlpatterns)),
        url(r'^manage/ovh/',
            decorated_includes(login_required, include(ovh.urls.management_urlpatterns))),
    )
)

urlpatterns += required(
    app_enabled('oxyd'),
    patterns('',
        url(r'^oxyd/', include(oxyd.urls.urlpatterns)),
        url(r'^manage/oxyd/',
            decorated_includes(login_required, include(oxyd.urls.management_urlpatterns))),
    )
)

urlpatterns += required(
    app_enabled('pastell'),
    patterns('',
        url(r'^pastell/', include(pastell.urls.urlpatterns)),
        url(r'^manage/pastell/',
            decorated_includes(login_required, include(pastell.urls.management_urlpatterns))),
    )
)

urlpatterns += required(
    app_enabled('concerto'),
    patterns('',
        url(r'^concerto/', include(concerto.urls.urlpatterns)),
        url(r'^manage/concerto/',
            decorated_includes(login_required, include(concerto.urls.management_urlpatterns))),
    )
)

urlpatterns += required(
    app_enabled('bdp'),
    patterns('',
        url(r'^bdp/', include(bdp.urls.urlpatterns)),
        url(r'^manage/bdp/',
            decorated_includes(login_required, include(bdp.urls.management_urlpatterns))),
    )
)

urlpatterns += required(
    app_enabled('base_adresse'),
    patterns('',
        url(r'^base_adresse/', include(base_adresse.urls.urlpatterns)),
        url(r'^manage/base_adresse/',
            decorated_includes(login_required, include(base_adresse.urls.management_urlpatterns))),
    )
)

# add patterns from apps
urlpatterns = register_apps_urls(urlpatterns)

# add authentication patterns
urlpatterns += patterns('',
    url(r'^logout/$', logout, name='logout'),
    url(r'^login/$', login, name='auth_login'),
)

if 'mellon' in settings.INSTALLED_APPS:
    urlpatterns += patterns('', url(r'^accounts/mellon/', include('mellon.urls')))


# activate URL for installed apps only
for app, d in LEGACY_APPS_PATTERNS.items():
    if 'passerelle.%s' % app in settings.INSTALLED_APPS:
        urlpatterns += patterns('',
            url(r'^%s/' % d['url'], include('passerelle.%s.urls' % app),
                {'resource_name': d['name']}),
        )

from django.contrib.staticfiles.urls import staticfiles_urlpatterns
urlpatterns += staticfiles_urlpatterns()
