#!/usr/bin/python

import os
import subprocess

from distutils.command.sdist import sdist
from setuptools import setup, find_packages

def get_version():
    if os.path.exists('VERSION'):
        version_file = open('VERSION', 'r')
        version = version_file.read()
        version_file.close()
        return version
    if os.path.exists('.git'):
        p = subprocess.Popen(['git','describe','--match=v*'], stdout=subprocess.PIPE)
        result = p.communicate()[0]
        version = result.split()[0][1:]
        version = version.replace('-', '.')
        return version
    return '0'

class eo_sdist(sdist):

    def run(self):
        print "creating VERSION file"
        if os.path.exists('VERSION'):
            os.remove('VERSION')
        version = get_version()
        version_file = open('VERSION', 'w')
        version_file.write(version)
        version_file.close()
        sdist.run(self)
        print "removing VERSION file"
        if os.path.exists('VERSION'):
            os.remove('VERSION')

setup(name='passerelle',
        version=get_version(),
        license='AGPLv3',
        description='Passerelle provides an uniform access to multiple data sources and services.',
        url='https://dev.entrouvert.org/projects/passerelle/',
        download_url='http://repos.entrouvert.org/passerelle.git/',
        author="Entr'ouvert",
        author_email="info@entrouvert.com",
        packages=find_packages(os.path.dirname(__file__) or '.'),
        scripts=['manage.py'],
        include_package_data=True,
        install_requires=[
            'django >= 1.7, <1.8',
            'django-model-utils',
            'django-jsonresponse==0.10',
            'django-jsonfield >= 0.9.3',
            'requests',
            'gadjo',
        ],
        cmdclass={'sdist': eo_sdist},
)
